@@ -223,6 +223,7 @@ namespace gnote {
   {
     if(!m_prefsdlg) {
       m_prefsdlg = std::make_unique<PreferencesDialog>(*this, default_note_manager());
+      m_prefsdlg->set_modal(true);
       m_prefsdlg->set_transient_for(get_main_window());
       m_prefsdlg->signal_response().connect(
         sigc::mem_fun(*this, &Gnote::on_preferences_response));
@@ -235,7 +236,7 @@ namespace gnote {
     utils::show_help("gnote", "", get_main_window());
   }
 
-  void Gnote::on_show_help_shortcust_action(const Glib::VariantBase&)
+  void Gnote::on_show_help_shortcuts_action(const Glib::VariantBase&)
   {
     Glib::RefPtr<Gtk::Builder> builder = Gtk::Builder::create_from_file(DATADIR"/gnote/shortcuts-gnote.ui");
     auto win = builder->get_widget<Gtk::ShortcutsWindow >("shortcuts-gnote");
@@ -244,6 +245,7 @@ namespace gnote {
       return;
     }
 
+    win->set_transient_for(get_main_window());
     manage(win)->show();
   }
 
@@ -282,6 +284,7 @@ namespace gnote {
     about->set_translator_credits(translators);
     MainWindow & recent_changes = get_main_window();
     if(recent_changes.get_visible()) {
+      about->set_modal(true);
       about->set_transient_for(recent_changes);
       recent_changes.present();
     }
@@ -308,6 +311,8 @@ namespace gnote {
     NoteRecentChanges *win = new NoteRecentChanges(*this, default_note_manager());
     win->signal_hide().connect([this, win]() { on_main_window_closed(win); });
     add_window(*win);
+    auto group = Gtk::WindowGroup::create();
+    group->add_window(*win);
     return *win;
   }
 
@@ -408,7 +413,7 @@ namespace gnote {
       sigc::mem_fun(*this, &Gnote::on_show_preferences_action));
     m_action_manager.get_app_action("sync-notes")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::open_note_sync_window));
     m_action_manager.get_app_action("help-contents")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_help_action));
-    m_action_manager.get_app_action("help-shortcuts")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_help_shortcust_action));
+    m_action_manager.get_app_action("help-shortcuts")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_help_shortcuts_action));
     m_action_manager.get_app_action("about")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_about_action));
 
     add_app_actions(m_action_manager.get_app_actions());
