@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2016,2019,2022-2023 Aurimas Cernius
+ * Copyright (C) 2010-2016,2019,2022-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -37,14 +37,9 @@
 namespace gnote {
 namespace notebooks {
 
-  Tag::Ptr           NotebookNoteAddin::s_templateTag;
-
-  Tag::Ptr NotebookNoteAddin::get_template_tag() const
+  Tag &NotebookNoteAddin::get_template_tag() const
   {
-    if(!s_templateTag) {
-      s_templateTag = manager().tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
-    }
-    return s_templateTag;
+    return manager().tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
   }
   
 
