@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2019,2022-2024 Aurimas Cernius
+ * Copyright (C) 2011-2014,2019,2022-2025 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -199,8 +199,12 @@ namespace gnote {
     NotebooksView::NotebooksView(NoteManagerBase & manager, const Glib::RefPtr<Gio::ListModel> & model)
       : Gtk::Box(Gtk::Orientation::VERTICAL)
       , m_note_manager(manager)
-      , m_list(make_selection_model(model), NotebookFactory::create())
+      , m_list(make_selection_model(model))
     {
+      auto column = Gtk::ColumnViewColumn::create(_("Notebook"), NotebookFactory::create());
+      column->set_expand(true);
+      m_list.append_column(column);
+
       m_new_button.set_icon_name("list-add-symbolic");
       m_new_button.set_tooltip_text(_("New Notebook"));
       m_new_button.set_has_frame(false);
@@ -372,9 +376,11 @@ namespace gnote {
       NotebookManager & notebook_manager = m_note_manager.notebook_manager();
       auto & new_notebook = notebook_manager.get_or_create_notebook(new_name);
       DBG_OUT("Renaming notebook '{%s}' to '{%s}'", old_notebook.get_name().c_str(), new_name.c_str());
-      auto notes = old_notebook.get_tag()->get_notes();
-      for(NoteBase *note : notes) {
-        notebook_manager.move_note_to_notebook(static_cast<Note&>(*note), new_notebook);
+      if(auto t = old_notebook.get_tag()) {
+        Tag &tag = t.value();
+        for(NoteBase *note : tag.get_notes()) {
+          notebook_manager.move_note_to_notebook(static_cast<Note&>(*note), new_notebook);
+        }
       }
       notebook_manager.delete_notebook(const_cast<Notebook&>(old_notebook));
       select_notebook(new_notebook);
