@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017,2019-2020,2022-2023 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019-2020,2022-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -22,6 +22,8 @@
 #ifndef _NOTEMANAGERBASE_HPP_
 #define _NOTEMANAGERBASE_HPP_
 
+#include <unordered_set>
+
 #include "itagmanager.hpp"
 #include "notebase.hpp"
 #include "triehit.hpp"
@@ -41,7 +43,7 @@ class TrieController;
 class NoteManagerBase
 {
 public:
-  typedef sigc::signal<void(const NoteBase::Ptr &)> ChangedHandler;
+  typedef sigc::signal<void(NoteBase&)> ChangedHandler;
 
   static Glib::ustring sanitize_xml_content(const Glib::ustring & xml_content);
   static Glib::ustring get_note_template_content(const Glib::ustring & title);
@@ -51,9 +53,13 @@ public:
   NoteManagerBase(IGnote & g);
   virtual ~NoteManagerBase();
 
+  IGnote& gnote()
+    {
+      return m_gnote;
+    }
   virtual notebooks::NotebookManager & notebook_manager() = 0;
   size_t trie_max_length();
-  TrieHit<NoteBase::WeakPtr>::ListPtr find_trie_matches(const Glib::ustring &);
+  TrieHit<Glib::ustring>::List find_trie_matches(const Glib::ustring &);
 
   virtual NoteArchiver & note_archiver() = 0;
   virtual const ITagManager & tag_manager() const = 0;
@@ -67,29 +73,66 @@ public:
     {
       return m_read_only;
     }
-  NoteBase::Ptr find(const Glib::ustring &) const;
-  NoteBase::Ptr find_by_uri(const Glib::ustring &) const;
-  NoteBase::List get_notes_linking_to(const Glib::ustring & title) const;
-  NoteBase::Ptr create();
-  NoteBase::Ptr create(Glib::ustring && title);
-  NoteBase::Ptr create(Glib::ustring && title, Glib::ustring && xml_content);
-  NoteBase::Ptr create_note_from_template(Glib::ustring && title, const NoteBase::Ptr & template_note);
-  virtual NoteBase::Ptr get_or_create_template_note();
-  NoteBase::Ptr find_template_note() const;
+  NoteBase::ORef find(const Glib::ustring &) const;
+  NoteBase::ORef find_by_uri(const Glib::ustring &) const;
+  template <typename F>
+  bool find_by_uri(const Glib::ustring & uri, const F & func) const
+    {
+      if(auto note = find_by_uri(uri)) {
+        func(*note);
+        return true;
+      }
+      return false;
+    }
+  std::vector<NoteBase::Ref> get_notes_linking_to(const Glib::ustring & title) const;
+  NoteBase & create();
+  NoteBase & create(Glib::ustring && title);
+  NoteBase & create(Glib::ustring && title, Glib::ustring && xml_content);
+  NoteBase & create_note_from_template(Glib::ustring && title, const NoteBase & template_note);
+  virtual NoteBase & get_or_create_template_note();
+  NoteBase::ORef find_template_note() const;
   Glib::ustring get_unique_name(const Glib::ustring & basename) const;
   void delete_note(NoteBase & note);
   // Import a note read from file_path
   // Will ensure the sanity including the unique title.
-  NoteBase::Ptr import_note(const Glib::ustring & file_path);
-  NoteBase::Ptr create_with_guid(Glib::ustring && title, Glib::ustring && guid);
+  NoteBase::ORef import_note(const Glib::ustring & file_path);
+  NoteBase & create_with_guid(Glib::ustring && title, Glib::ustring && guid);
 
   const Glib::ustring & notes_dir() const
     {
       return m_notes_dir;
     }
-  const NoteBase::List & get_notes() const
-    { 
-      return m_notes;
+  std::size_t note_count() const
+    {
+      return m_notes.size();
+    }
+
+  template <typename F>
+  void for_each(const F & func) const
+    {
+      for(const auto & note : m_notes) {
+        func(*note);
+      }
+    }
+
+  template <typename RetT, typename FuncT>
+  RetT search(const FuncT & func, const RetT & default_ret) const
+    {
+      RetT ret{default_ret};
+      for(const auto & note : m_notes) {
+        if(!func(*note, ret)) {
+          break;
+        }
+      }
+      return ret;
+    }
+
+  template <typename C, typename F>
+  void copy_to(C & container, const F & func) const
+    {
+      for(const auto & note : m_notes) {
+        func(container, note);
+      }
     }
 
   ChangedHandler signal_note_deleted;
@@ -102,18 +145,22 @@ protected:
   virtual void migrate_notes(const Glib::ustring & old_note_dir);
   /** add the note to the manager and setup signals */
   void add_note(NoteBase::Ptr);
-  void on_note_rename(const NoteBase::Ptr & note, const Glib::ustring & old_title);
-  void on_note_save(const NoteBase::Ptr & note);
-  virtual NoteBase::Ptr create_note_from_template(Glib::ustring && title, const NoteBase::Ptr & template_note, Glib::ustring && guid);
-  virtual NoteBase::Ptr create_note(Glib::ustring && title, Glib::ustring && body, Glib::ustring && guid = Glib::ustring());
-  virtual NoteBase::Ptr create_new_note(Glib::ustring && title, Glib::ustring && xml_content, Glib::ustring && guid);
+  void on_note_rename(const NoteBase & note, const Glib::ustring & old_title);
+  void on_note_save(NoteBase & note);
+  virtual NoteBase & create_note_from_template(Glib::ustring && title, const NoteBase & template_note, Glib::ustring && guid);
+  virtual NoteBase & create_note(Glib::ustring && title, Glib::ustring && body, Glib::ustring && guid = Glib::ustring());
+  virtual NoteBase & create_new_note(Glib::ustring && title, Glib::ustring && xml_content, Glib::ustring && guid);
   virtual NoteBase::Ptr note_create_new(Glib::ustring && title, Glib::ustring && file_name) = 0;
   Glib::ustring make_new_file_name() const;
   Glib::ustring make_new_file_name(const Glib::ustring & guid) const;
   virtual NoteBase::Ptr note_load(Glib::ustring && file_name) = 0;
 
-  IGnote & m_gnote;
-  NoteBase::List m_notes;
+  struct NoteHash
+  {
+    std::size_t operator()(const NoteBase::Ptr &) const noexcept;
+  };
+
+  std::unordered_set<NoteBase::Ptr, NoteHash> m_notes;
   Glib::ustring m_backup_dir;
   Glib::ustring m_default_note_template_title;
 private:
@@ -122,6 +169,7 @@ private:
   bool create_directory(const Glib::ustring & directory) const;
   TrieController *create_trie_controller();
 
+  IGnote & m_gnote;
   TrieController *m_trie_controller;
   Glib::ustring m_notes_dir;
   bool m_read_only;
