@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013-2014,2017,2019,2023 Aurimas Cernius
+ * Copyright (C) 2011,2013-2014,2017,2019,2023-2024 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -52,7 +52,7 @@ namespace gnote {
     Results temp_matches;
       
       // Skip over notes that are template notes
-    Tag::Ptr template_tag = m_manager.tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+    auto &template_tag = m_manager.tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
 
     m_manager.for_each([this, &temp_matches, template_tag, selected_notebook, case_sensitive, words=std::move(words), encoded_words=std::move(encoded_words)](NoteBase & note) {
       // Skip template notes
