@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2015,2017,2019-2024 Aurimas Cernius
+ * Copyright (C) 2010-2015,2017,2019-2025 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -70,18 +70,14 @@ private:
   void restore_matches_window();
   Gtk::Widget *make_notebooks_pane();
   void save_position();
-  void rename_notebook(const notebooks::Notebook& old_notebook, const Glib::ustring& new_name);
   void on_notebook_selection_changed(const notebooks::Notebook & notebook);
   void on_notebook_list_changed();
   void update_results();
   unsigned selected_note_count() const;
   std::vector<Note::Ref> get_selected_notes();
-  bool filter_notes(const Gtk::TreeIter<Gtk::TreeConstRow> &);
-  int compare_titles(const Gtk::TreeIter<Gtk::TreeConstRow> &, const Gtk::TreeIter<Gtk::TreeConstRow> &);
   void make_recent_notes_view();
   void select_notes(const std::vector<Note::Ref> &);
   bool filter_by_search(const Note &);
-  bool filter_by_tag(const Note &, const Tag::Ptr &);
   void on_row_activated(guint idx);
   void on_selection_changed(guint, guint);
   bool on_treeview_key_pressed(guint keyval, guint keycode, Gdk::ModifierType state);
@@ -142,6 +138,8 @@ private:
 
   Glib::RefPtr<Gtk::EventControllerKey> m_notes_widget_key_ctrl;
   RecentSearchColumnTypes m_find_combo_columns;
+  Gtk::Box m_notes_pane;
+  Gtk::Button m_delete_note_button;
   Gtk::ScrolledWindow m_matches_window;
   std::shared_ptr<Gtk::Grid> m_no_matches_box;
   notebooks::NotebooksView *m_notebooks_view;
