@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2017-2020 Aurimas Cernius
+ * Copyright (C) 2017-2020,2023 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -72,9 +72,9 @@ void SyncManager::delete_notes_in_main_thread(gnote::sync::SyncServer & server)
   delete_notes(server);
 }
 
-void SyncManager::note_save(const gnote::Note::Ptr & note)
+void SyncManager::note_save(const gnote::NoteBase & note)
 {
-  note->save();
+  const_cast<gnote::NoteBase&>(note).save();
 }
 
 void SyncManager::create_note_in_main_thread(const gnote::sync::NoteUpdate & noteUpdate)
@@ -82,14 +82,14 @@ void SyncManager::create_note_in_main_thread(const gnote::sync::NoteUpdate & not
   create_note(noteUpdate);
 }
 
-void SyncManager::update_note_in_main_thread(const gnote::Note::Ptr & existingNote, const gnote::sync::NoteUpdate & noteUpdate)
+void SyncManager::update_note_in_main_thread(const gnote::NoteBase & existing_note, const gnote::sync::NoteUpdate & note_update)
 {
-  update_note(existingNote, noteUpdate);
+  update_note(const_cast<gnote::NoteBase&>(existing_note), note_update);
 }
 
-void SyncManager::delete_note_in_main_thread(const gnote::Note::Ptr & existingNote)
+void SyncManager::delete_note_in_main_thread(const gnote::NoteBase & existing_note)
 {
-  delete_note(existingNote);
+  delete_note(const_cast<gnote::NoteBase&>(existing_note));
 }
 
 }
